@@ -342,12 +342,18 @@ class ISCSIConnector(base.BaseLinuxConnector, base_iscsi.BaseISCSIConnector):
         :type connection_properties: dict
         :returns: list of tuples of (ip, iqn, lun)
         """
+        ip, port = connection_properties['target_portal'].rsplit(':', 1)
+        # NOTE(geguileo): I don't know if IPv6 will be reported with []
+        # or not, so we'll make them optional.
+        ip = ip.replace('[', '\[?').replace(']', '\]?')
         out = self._run_iscsiadm_bare(['-m', 'discoverydb',
                                        '-o', 'show',
                                        '-P', 1])[0] or ""
-        regex = ('^SENDTARGETS:\n.*?^DiscoveryAddress: ' +
-                 connection_properties['target_portal'] +
-                 '.*?\n(.*?)^(?:DiscoveryAddress|iSNS):.*')
+        regex = ''.join(('^SENDTARGETS:\n.*?^DiscoveryAddress: ',
+                         ip, ',', port,
+                         '.*?\n(.*?)^(?:DiscoveryAddress|iSNS):.*'))
+        LOG.debug('Regex to get portals from discoverydb: %s', regex)
+
         info = re.search(regex, out, re.DOTALL | re.MULTILINE)
 
         ips = []
@@ -948,13 +954,11 @@ class ISCSIConnector(base.BaseLinuxConnector, base_iscsi.BaseISCSIConnector):
             self._run_iscsiadm(connection_properties,
                                ('--interface', self._get_transport(),
                                 '--op', 'new'))
-            # Try to set the scan mode to manual
-            res = self._iscsiadm_update(connection_properties,
-                                        'node.session.scan', 'manual',
-                                        check_exit_code=False)
-            manual_scan = not res[1]
-        else:
-            manual_scan = 'node.session.scan = manual' in out
+        # Try to set the scan mode to manual
+        res = self._iscsiadm_update(connection_properties,
+                                    'node.session.scan', 'manual',
+                                    check_exit_code=False)
+        manual_scan = not res[1]
 
         if connection_properties.get('auth_method'):
             self._iscsiadm_update(connection_properties,
