@@ -539,17 +539,20 @@ class ISCSIConnectorTestCase(test_connector.ConnectorTestCase):
     @mock.patch.object(iscsi.ISCSIConnector, '_run_iscsiadm_bare')
     def test_get_discoverydb_portals(self, is_iser, iscsiadm_mock,
                                      transport_mock):
-        params = {'iqn1': self.SINGLE_CON_PROPS['target_iqn'],
-                  'iqn2': 'iqn.2004-04.com.qnap:ts-831x:iscsi.cinder-2017.9ef',
-                  'ip1': self.SINGLE_CON_PROPS['target_portal'],
-                  'ip2': '192.168.1.3:3260',
-                  'transport': 'iser' if is_iser else 'default',
-                  'other_transport': 'default' if is_iser else 'iser'}
+        params = {
+            'iqn1': self.SINGLE_CON_PROPS['target_iqn'],
+            'iqn2': 'iqn.2004-04.com.qnap:ts-831x:iscsi.cinder-2017.9ef',
+            'addr': self.SINGLE_CON_PROPS['target_portal'].replace(':', ','),
+            'ip1': self.SINGLE_CON_PROPS['target_portal'],
+            'ip2': '192.168.1.3:3260',
+            'transport': 'iser' if is_iser else 'default',
+            'other_transport': 'default' if is_iser else 'iser',
+        }
 
         iscsiadm_mock.return_value = (
             'SENDTARGETS:\n'
             'DiscoveryAddress: 192.168.1.33,3260\n'
-            'DiscoveryAddress: %(ip1)s\n'
+            'DiscoveryAddress: %(addr)s\n'
             'Target: %(iqn1)s\n'
             '	Portal: %(ip2)s,1\n'
             '		Iface Name: %(transport)s\n'
@@ -613,12 +616,15 @@ class ISCSIConnectorTestCase(test_connector.ConnectorTestCase):
     def test_get_discoverydb_portals_error_is_present(self, iscsiadm_mock,
                                                       transport_mock):
         """DiscoveryAddress is present but wrong iterface."""
-        params = {'iqn': self.SINGLE_CON_PROPS['target_iqn'],
-                  'ip': self.SINGLE_CON_PROPS['target_portal']}
+        params = {
+            'iqn': self.SINGLE_CON_PROPS['target_iqn'],
+            'addr': self.SINGLE_CON_PROPS['target_portal'].replace(':', ','),
+            'ip': self.SINGLE_CON_PROPS['target_portal'],
+        }
         iscsiadm_mock.return_value = (
             'SENDTARGETS:\n'
             'DiscoveryAddress: 192.168.1.33,3260\n'
-            'DiscoveryAddress: %(ip)s\n'
+            'DiscoveryAddress: %(addr)s\n'
             'Target: %(iqn)s\n'
             '	Portal: %(ip)s,1\n'
             '		Iface Name: iser\n'
@@ -979,11 +985,12 @@ Setting up iSCSI targets: unused
         con_props.update(auth_method='CHAP', auth_username='user',
                          auth_password='pwd')
         res = self.connector._connect_to_iscsi_portal(con_props)
-        # False refers to "manual scans", so we have automatic iscsi scans
-        self.assertEqual((session, False), res)
+        # False refers to "manual scans", so we have manual iscsi scans
+        self.assertEqual((session, True), res)
         prefix = 'iscsiadm -m node -T tgt1 -p ip1:port1'
         expected_cmds = [
             prefix,
+            prefix + ' --op update -n node.session.scan -v manual',
             prefix + ' --op update -n node.session.auth.authmethod -v CHAP',
             prefix + ' --op update -n node.session.auth.username -v user',
             prefix + ' --op update -n node.session.auth.password -v pwd',
@@ -991,36 +998,17 @@ Setting up iSCSI targets: unused
         self.assertListEqual(expected_cmds, self.cmds)
         get_sessions_mock.assert_called_once_with()
 
-    @ddt.data('auto', 'manual')
-    @mock.patch.object(iscsi.ISCSIConnector, '_get_iscsi_sessions_full')
-    def test_connect_to_iscsi_portal_manual_scan_feature(self, manual_scan,
-                                                         get_sessions_mock):
-        """Node and session already exists and iscsi supports manual scans."""
-        session = 'session2'
-        get_sessions_mock.return_value = [('tcp:', session, 'ip1:port1',
-                                           '-1', 'tgt1')]
-        con_props = self.CON_PROPS.copy()
-        node_props = ('node.startup = automatic\nnode.session.scan = ' +
-                      manual_scan)
-        with mock.patch.object(self.connector, '_execute') as exec_mock:
-            exec_mock.side_effect = [(node_props, None)]
-            res = self.connector._connect_to_iscsi_portal(con_props)
-        # False refers to "manual scans", so we have automatic iscsi scans
-        self.assertEqual((session, manual_scan == 'manual'), res)
-
-        actual_cmds = [' '.join(args[0]) for args in exec_mock.call_args_list]
-        self.assertListEqual(['iscsiadm -m node -T tgt1 -p ip1:port1'],
-                             actual_cmds)
-        get_sessions_mock.assert_called_once_with()
-
     @mock.patch.object(iscsi.ISCSIConnector, '_get_iscsi_sessions_full')
     def test_connect_to_iscsi_portal_fail_login(self, get_sessions_mock):
         get_sessions_mock.return_value = []
         with mock.patch.object(self.connector, '_execute') as exec_mock:
-            exec_mock.side_effect = [('', None), putils.ProcessExecutionError]
+            exec_mock.side_effect = [('', None), ('', None),
+                                     putils.ProcessExecutionError]
             res = self.connector._connect_to_iscsi_portal(self.CON_PROPS)
         self.assertEqual((None, None), res)
         expected_cmds = ['iscsiadm -m node -T tgt1 -p ip1:port1',
+                         'iscsiadm -m node -T tgt1 -p ip1:port1 '
+                         '--op update -n node.session.scan -v manual',
                          'iscsiadm -m node -T tgt1 -p ip1:port1 --login']
         actual_cmds = [' '.join(args[0]) for args in exec_mock.call_args_list]
         self.assertListEqual(expected_cmds, actual_cmds)
